@@ -28,6 +28,8 @@ class FeedModifier(ABC):
     Concrete subclasses correspond to the specific kind of feed, i.e. RSS or Atom.
     """
 
+    _bool_attributes = {"run_forever", "overwrite_entry_ids"}
+
     def __init__(
         self,
         path: str | Path | None,
@@ -36,6 +38,7 @@ class FeedModifier(ABC):
         run_forever: Optional[bool] = None,
         initialize_all_pubdates: bool = False,
         overwrite_self_link: str | None = None,
+        overwrite_entry_ids: bool | None = None,
         title_kwargs: dict[str, Any] = {},
         entry_title_kwargs: dict[str, str] = {},
     ) -> None:
@@ -78,6 +81,7 @@ class FeedModifier(ABC):
             "run_forever": "True",
             "original_title": self._channel["title"].text or "",
             "original_self_link": self.source_url(),
+            "overwrite_entry_ids": "False",
             "title_prefix": None,
             "title_suffix": None,
             "entry_title_prefix": None,
@@ -98,7 +102,10 @@ class FeedModifier(ABC):
                 self.update_entry_pubdate(entry, datetime.now(timezone.utc))
 
         if run_forever is not None:
-            self.run_forever = run_forever
+            self["run_forever"] = run_forever
+
+        if overwrite_entry_ids is not None:
+            self["overwrite_entry_ids"] = overwrite_entry_ids
 
         if overwrite_self_link:
             self._overwrite_self_link(new_self_link=overwrite_self_link)
@@ -272,34 +279,25 @@ class FeedModifier(ABC):
             )
         return response.content
 
-    @property
-    def run_forever(self):
-        """Getter function for retrieving `forever` text from the etree."""
-        return self._meta_channel["run_forever"].text.lower() == "true"
-
-    @run_forever.setter
-    def run_forever(self, forever: bool | str):
-        """Setter function for setting `forever` text in the etree."""
-        if str(forever).capitalize() in {"True", "False"}:
-            self._meta_channel["run_forever"].text = str(forever).capitalize()
-        else:
-            raise ValueError(
-                f"Invalid value {forever} for `forever`: expected True or False."
-            )
-        pass
-
     def __getitem__(self, name) -> str:
         """Access meta channel subelements as if they're items of the FeedModifier."""
         if name in self._meta_channel:
-            return self._meta_channel[name].text
+            text = self._meta_channel[name].text
         elif name in self._channel:
-            return self._channel[name].text
+            text = self._channel[name].text
         else:
             raise KeyError(name)
+        return text if name not in self._bool_attributes else bool(text)
 
     def __setitem__(self, name, value):
         """Access meta channel subelements as if they're items of the FeedModifier."""
-        self._meta_channel[name].text = value
+        if name in self._bool_attributes and str(value).capitalize() not in {"True", "False"}:
+            raise ValueError(
+                f"Invalid value {value} for attribute {name}: expected True or False."
+            )
+        self._meta_channel[name].text = (
+            value if name not in self._bool_attributes else str(value).capitalize()
+        )
         pass
 
     def __delitem__(self, name):
@@ -399,7 +397,7 @@ class FeedModifier(ABC):
             if meta_entry["reran"].text.lower() == "false"
         ]
 
-        if len(not_reran) == 0 and self.run_forever:
+        if len(not_reran) == 0 and self["run_forever"]:
             self._mark_all_not_reran()
             return self.feed_entries()
         else:
@@ -786,7 +784,7 @@ class AtomFeedModifier(FeedModifier):
         Returns the subelement containing the new uuid.
         """
         entry["id"].text = self._generate_entry_uuid(entry)
-        entry["guid"].isPermaLink = "false"
+        entry["id"].isPermaLink = "false"
         return entry["id"]
 
     @staticmethod
